# CLI for Google Trends

Use this to quickly access the [Google Trends API](https://trends.google.com/trends/) via Command Line.

## Installation
```bash
pip install atrends
```

## Usage

#### Run `trends` with any number of arguments

## Example
```bash
trends flask django react
```

![](https://i.imgur.com/JzzNAZU.png)

## Custom:
Edit the category, timeframe, colors, lines, in main.py
